@@ -421,10 +421,10 @@ std::ostream &operator<<(std::ostream &o, Section const &section)
 }
 
 // table
-Variable<Table::Cell> &Table::getCell(int id)
+MWAWVariable<Table::Cell> &Table::getCell(int id)
 {
   if (id < 0) {
-    static Variable<Table::Cell> badCell;
+    static MWAWVariable<Table::Cell> badCell;
     MWAW_DEBUG_MSG(("MsWrdStruct::Table::getCell: can not return a negative cell id\n"));
     return badCell;
   }
@@ -488,7 +488,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     input->seek(pos+2+sz, librevenge::RVNG_SEEK_SET);
     return true;
   }
-  case 0x92: // table alignement
+  case 0x92: // table alignment
     if (dSz < 3) return false;
     val = (int) input->readULong(2);
     switch (val&3) {
@@ -509,7 +509,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     }
     if (val&0xFFFC) f << "#align=" << std::hex << (val&0xFFFC) << std::dec << ",";
     break;
-  case 0x93: // table alignement indent
+  case 0x93: // table alignment indent
     if (dSz < 3) return false;
     m_indent = float(input->readLong(2))/1440.f;
     return true;
@@ -576,7 +576,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     std::string bExtra;
     MWAWBorder border = getBorder((int) input->readULong(2), bExtra);
     for (int i = firstCol; i < lastCol; i++) {
-      Variable<Cell> &cell = getCell(i);
+      MWAWVariable<Cell> &cell = getCell(i);
       if (cell->m_borders.size() < maxVal)
         cell->m_borders.resize(maxVal);
       if (val&1) cell->m_borders[0] = border;
@@ -616,7 +616,7 @@ void Table::insert(Table const &table)
   }
   size_t tNumCells = table.m_cells.size();
   if (tNumCells > m_cells.size())
-    m_cells.resize(tNumCells, Variable<Cell>());
+    m_cells.resize(tNumCells, MWAWVariable<Cell>());
   for (size_t i=0; i < tNumCells; i++) {
     if (!m_cells[i].isSet())
       m_cells[i] = table.m_cells[i];
@@ -954,7 +954,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
     else if (c == 0x11) m_margins[1] = val/1440.;
     else m_margins[2] = val/1440.;
     return true;
-  case 0x14: // alignement : 240 normal, 480 : double, ..
+  case 0x14: // alignment : 240 normal, 480 : double, ..
     if (dSz < 3) return false;
     val = (int) input->readLong(2);
     m_interline=double(val)/1440.;
