@@ -350,10 +350,10 @@ libmwaw::DebugFile &NisusWrtParser::rsrcAscii()
 ////////////////////////////////////////////////////////////
 // position and height
 ////////////////////////////////////////////////////////////
-Vec2f NisusWrtParser::getPageLeftTop() const
+MWAWVec2f NisusWrtParser::getPageLeftTop() const
 {
-  return Vec2f(float(getPageSpan().getMarginLeft()),
-               float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
+  return MWAWVec2f(float(getPageSpan().getMarginLeft()),
+                   float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
 }
 
 void NisusWrtParser::getColumnInfo(int &numColumns, float &colSep) const
@@ -505,9 +505,7 @@ void NisusWrtParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void NisusWrtParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  assert(getInput().get() != 0 && getRSRCParser());
-
-  if (!checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !getRSRCParser() || !checkHeader(0L))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
@@ -785,34 +783,31 @@ bool NisusWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   MWAWInputStreamPtr input = getInput();
   if (!input || !input->hasDataFork() || !getRSRCParser())
     return false;
-  MWAWRSRCParser::Version vers;
+  MWAWRSRCParser::Version applVersion, docVersion;
   // read the Nisus version
-  int nisusVersion = -1;
   MWAWEntry entry = getRSRCParser()->getEntry("vers", 2002);
   if (!entry.valid()) entry = getRSRCParser()->getEntry("vers", 2);
-  if (entry.valid() && getRSRCParser()->parseVers(entry, vers))
-    nisusVersion = vers.m_majorVersion;
-  else if (nisusVersion==-1) {
+  // read the application format version
+  if (!entry.valid() || !getRSRCParser()->parseVers(entry, applVersion)) {
     MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: can not find the Nisus version\n"));
   }
-
   // read the file format version
   entry = getRSRCParser()->getEntry("vers", 1);
-  if (!entry.valid() || !getRSRCParser()->parseVers(entry, vers)) {
+  if (!entry.valid() || !getRSRCParser()->parseVers(entry, docVersion)) {
     MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: can not find the Nisus file format version\n"));
     return false;
   }
-  switch (vers.m_majorVersion) {
+  switch (docVersion.m_majorVersion) {
   case 3:
   case 4:
-    MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: find Nisus %d file with file format version %d\n", nisusVersion, vers.m_majorVersion));
+    MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: find Nisus %d file with file format version %d\n", applVersion.m_majorVersion, docVersion.m_majorVersion));
     break;
   default:
-    MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: find Nisus %d file with unknown file format version %d\n", nisusVersion, vers.m_majorVersion));
+    MWAW_DEBUG_MSG(("NisusWrtParser::checkHeader: find Nisus %d file with unknown file format version %d\n", applVersion.m_majorVersion, docVersion.m_majorVersion));
     return false;
   }
 
-  setVersion(vers.m_majorVersion);
+  setVersion(docVersion.m_majorVersion);
   if (header)
     header->reset(MWAWDocument::MWAW_T_NISUSWRITER, version());
 
@@ -1582,20 +1577,20 @@ bool NisusWrtParser::readPrintInfo(MWAWEntry const &entry)
   else
     f << "Entries(PrintInfo):" << info;
 
-  Vec2i paperSize = info.paper().size();
-  Vec2i pageSize = info.page().size();
+  MWAWVec2i paperSize = info.paper().size();
+  MWAWVec2i pageSize = info.page().size();
   if (pageSize.x() <= 0 || pageSize.y() <= 0 ||
       paperSize.x() <= 0 || paperSize.y() <= 0) return false;
 
   // define margin from print info
-  Vec2i lTopMargin= -1 * info.paper().pos(0);
-  Vec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
+  MWAWVec2i lTopMargin= -1 * info.paper().pos(0);
+  MWAWVec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
 
   // move margin left | top
   int decalX = lTopMargin.x() > 14 ? lTopMargin.x()-14 : 0;
   int decalY = lTopMargin.y() > 14 ? lTopMargin.y()-14 : 0;
-  lTopMargin -= Vec2i(decalX, decalY);
-  rBotMargin += Vec2i(decalX, decalY);
+  lTopMargin -= MWAWVec2i(decalX, decalY);
+  rBotMargin += MWAWVec2i(decalX, decalY);
 
   // decrease right | bottom
   int rightMarg = rBotMargin.x() -10;
@@ -1653,19 +1648,19 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   val = input->readLong(2); // always 0x0
   if (val) f << "f2=" << val << ",";
 
-  Box2i boxes[3];
+  MWAWBox2i boxes[3];
   for (int i = 0; i < 3; i++) {
     int dim[4];
     for (int d = 0; d < 4; d++)
       dim[d] = (int) input->readLong(2);
-    boxes[i] = Box2i(Vec2i(dim[1],dim[0]),Vec2i(dim[3],dim[2]));
+    boxes[i] = MWAWBox2i(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
   }
   f << "page=" << boxes[0] << ",";
   f << "page[text]=" << boxes[1] << ",";
   f << "page[columns]=" << boxes[2] << ",";
-  Vec2i pageDim = boxes[0].size();
-  Vec2i LT=boxes[1][0]-boxes[0][0];
-  Vec2i RB=boxes[0][1]-boxes[1][1];
+  MWAWVec2i pageDim = boxes[0].size();
+  MWAWVec2i LT=boxes[1][0]-boxes[0][0];
+  MWAWVec2i RB=boxes[0][1]-boxes[1][1];
   bool dimOk=pageDim[0] > 0 && pageDim[1] > 0 &&
              LT[0] >= 0 && LT[1] >= 0 && RB[0] >= 0 && RB[1] >= 0;
   if (!dimOk && m_state->m_isTextDocument) {
@@ -1740,7 +1735,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   int dim[4];
   for (int d = 0; d < 4; d++)
     dim[d] = (int) input->readLong(2);
-  Box2i realPage = Box2i(Vec2i(dim[1],dim[0]), Vec2i(dim[3],dim[2]));
+  MWAWBox2i realPage = MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
   if (dimOk && realPage.size()[0] >= pageDim[0] && realPage.size()[1] >= pageDim[1]) {
     LT -= realPage[0];
     RB += (realPage[1]-boxes[0][1]);
