@@ -65,14 +65,14 @@ struct File {
     m_fileVersion(), m_appliVersion(), m_rsrcMissingMessage(""), m_rsrcResult(""),
     m_dataResult(), m_printFileName(false)
   {
-    if (!m_fName.length()) {
+    if (m_fName.empty()) {
       std::cerr << "File::File: call without path\n";
       throw libmwaw_tools::Exception();
     }
 
     // check if it is a regular file
     struct stat status;
-    if (stat(path, &status) == -1) {
+    if (!path || stat(path, &status) == -1) {
       std::cerr << "File::File: the file " << m_fName << " cannot be read\n";
       throw libmwaw_tools::Exception();
     }
@@ -269,8 +269,13 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="CARO") {
     checkFInfoType("PDF ", "Acrobat PDF");
   }
+  else if (m_fInfoCreator=="C#+A") {
+    checkFInfoType("C#+D","RagTime 5") || checkFInfoType("C#+F","RagTime 5[form]") ||
+    checkFInfoType("RagTime 5");
+  }
   else if (m_fInfoCreator=="CDrw") {
-    checkFInfoType("dDraw", "ClarisDraw") || checkFInfoType("ClarisDraw");
+    checkFInfoType("dDrw", "ClarisDraw") || checkFInfoType("dDst", "ClarisDraw[stationary]") ||
+    checkFInfoType("iLib", "ClarisDraw[library]") || checkFInfoType("ClarisDraw");
   }
   else if (m_fInfoCreator=="DkmR") {
     checkFInfoType("TEXT","Basic text(created by DOCMaker)") || checkFInfoType("DOCMaker");
@@ -313,6 +318,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="HMdr") {
     checkFInfoType("DRD2","HanMac Word-K") || checkFInfoType("HanMac Word-K");
   }
+  else if (m_fInfoCreator=="L123") {
+    checkFInfoType("LWKS","Lotus123") || checkFInfoType("Lotus123");
+  }
   else if (m_fInfoCreator=="LWTE") {
     checkFInfoType("TEXT","LightWayText") || checkFInfoType("MACR","LightWayText[MACR]") ||
     checkFInfoType("pref","LightWayText[Preferences]") ||
@@ -324,8 +332,11 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MACA") {
     checkFInfoType("WORD","MacWrite") || checkFInfoType("MacWrite");
   }
-  else if (m_fInfoCreator=="MACD") {   // checkme
-    checkFInfoType("DRWG","MacDraw[unsure]");
+  else if (m_fInfoCreator=="MACD") {
+    checkFInfoType("DRWG","MacDraft 1.0") || checkFInfoType("MacDraft 1.0");
+  }
+  else if (m_fInfoCreator=="MD40") {
+    checkFInfoType("MDDC","MacDraft 5.0") || checkFInfoType("MacDraft 5.0");
   }
   else if (m_fInfoCreator=="MDsr") {
     checkFInfoType("APPL","MacDoc(appli)");
@@ -333,11 +344,14 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MDvr") {
     checkFInfoType("MDdc","MacDoc") || checkFInfoType("MacDoc");
   }
+  else if (m_fInfoCreator=="MDFT") {
+    checkFInfoType("DRWG","MacDraft 1.2") || checkFInfoType("MacDraft 1.2");
+  }
   else if (m_fInfoCreator=="MDRW") {
     checkFInfoType("DRWG","MacDraw") || checkFInfoType("MacDraw");
   }
   else if (m_fInfoCreator=="MDPL") {
-    checkFInfoType("DRWG","MacDraw II") || checkFInfoType("MacDraw II");
+    checkFInfoType("DRWG","MacDraw II") || checkFInfoType("STAT","MacDraw II(template)") || checkFInfoType("MacDraw II");
   }
   else if (m_fInfoCreator=="MMBB") {
     checkFInfoType("MBBT","Mariner Write") || checkFInfoType("Mariner Write");
@@ -463,7 +477,7 @@ bool File::readFileInformation()
     checkFInfoType("curs","CursorAnimator") || checkFInfoType("CursorAnimator");
   }
   else if (m_fInfoCreator=="dPro") {
-    checkFInfoType("dDoc","MacDraw Pro") || checkFInfoType("MacDraw Pro");
+    checkFInfoType("dDoc","MacDraw Pro") || checkFInfoType("dLib","MacDraw Pro(slide)") || checkFInfoType("MacDraw Pro");
   }
   else if (m_fInfoCreator=="eDcR") {
     checkFInfoType("eDoc","eDOC") || checkFInfoType("eDOC");
@@ -545,6 +559,10 @@ bool File::readDataInformation()
       m_dataResult.push_back("BeagleWorks/WordPerfect Works[Unknown]");
     return true;
   }
+  if (val[0]==0x4323 && val[1]==0x2b44 && val[2]==0xa443 && val[3]==0x4da5 && val[4]==0x4864) {
+    m_dataResult.push_back("RagTime 5-6");
+    return true;
+  }
   if (val[0]==0x5772 && val[1]==0x6974 && val[2]==0x654e && val[3]==0x6f77 && val[4]==2) {
     m_dataResult.push_back("WriteNow 3-4");
     return true;
@@ -571,10 +589,36 @@ bool File::readDataInformation()
     m_dataResult.push_back("More 3");
     return true;
   }
+  if (val[0]==2 && val[1]==0 && val[2]==2 && val[3]==0x262 && val[4]==0x262) {
+    m_dataResult.push_back("MacDraft");
+    return true;
+  }
   if (val[0]==0x4646 && val[1]==0x4646 && val[2]==0x3030 && val[3]==0x3030) {
     m_dataResult.push_back("Mariner Write");
     return true;
   }
+  if (val[0]==0x4452 && val[1]==0x5747) { // DRWG
+    if (val[2]==0x4d44) { // MD
+      m_dataResult.push_back("MacDraw");
+      return true;
+    }
+    if (val[2]==0 || val[2]==0x4432) { // nothing or D2
+      m_dataResult.push_back("MacDraw II");
+      return true;
+    }
+  }
+  if (val[0]==0x5354 && val[1]==0x4154 && (val[2]==0||val[2]==0x4432)) { // STATD2
+    m_dataResult.push_back("MacDraw II(template)");
+    return true;
+  }
+  if (val[0]==0x6444 && val[1]==0x6f63 && val[2]==0x4432) { // dDocD2
+    m_dataResult.push_back("MacDraw Pro");
+    return true;
+  }
+  if (val[0]==0x644c && val[1]==0x6962 && val[2]==0x4432) { // dLibD2
+    m_dataResult.push_back("MacDraw Pro(slide)");
+    return true;
+  }
   if (val[0]==0x4859 && val[1]==0x4c53 && val[2]==0x0210) {
     m_dataResult.push_back("HanMac Word-K");
     return true;
@@ -677,6 +721,13 @@ bool File::readDataInformation()
       return true;
     }
   }
+  if ((val[0]==0x100||val[0]==0x200) && val[2]==0x4558 && val[3]==0x5057) {
+    if (val[0]==0x100)
+      m_dataResult.push_back("ClarisDraw");
+    else
+      m_dataResult.push_back("ClarisDraw[library]");
+    return true;
+  }
   // less discriminant
   if ((val[0]==0xfe32 && val[1]==0) || (val[0]==0xfe34 && val[1]==0) ||
       (val[0] == 0xfe37 && (val[1] == 0x23 || val[1] == 0x1c))) {
@@ -719,6 +770,9 @@ bool File::readDataInformation()
     m_dataResult.push_back("Microsoft Word 2.0[pc]");
     return true;
   }
+  if (val[0]==0x4D44) { // MD
+    m_dataResult.push_back("MacDraw v0[unsure]");
+  }
   if (val[0] == 3 || val[0] == 6) {
     int numParaPos = val[0] == 3 ? 2 : 1;
     if (val[numParaPos] < 0x1000 && val[numParaPos+1] < 0x100 && val[numParaPos+2] < 0x100)
